#[repr(i32)]pub enum VelocityChangeTaskRationale {
Correctional = 0,
OrbitEscape = 1,
OrbitEnter = 2,
}Variants
Implementations
Sourceimpl VelocityChangeTaskRationale
impl VelocityChangeTaskRationale
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of VelocityChangeTaskRationale.
Sourcepub fn from_i32(value: i32) -> Option<VelocityChangeTaskRationale>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<VelocityChangeTaskRationale>
Converts an i32 to a VelocityChangeTaskRationale, or None if value is not a valid variant.