pub struct BurnSequence {Show 14 fields
pub rational: i32,
pub target_x: u32,
pub target_y: u32,
pub add_target_x: Option<u32>,
pub add_target_y: Option<u32>,
pub position_x: Vec<u32>,
pub position_y: Vec<u32>,
pub velocity_x: Vec<f32>,
pub velocity_y: Vec<f32>,
pub acc_dt: u32,
pub detumble_dt: u32,
pub rem_angle_dev: f32,
pub min_charge: f32,
pub min_fuel: f32,
}Fields
rational: i32target_x: u32target_y: u32add_target_x: Option<u32>add_target_y: Option<u32>position_x: Vec<u32>position_y: Vec<u32>velocity_x: Vec<f32>velocity_y: Vec<f32>acc_dt: u32detumble_dt: u32rem_angle_dev: f32min_charge: f32min_fuel: f32Implementations
Sourceimpl BurnSequence
impl BurnSequence
Sourcepub fn rational(&self) -> VelocityChangeTaskRationale
pub fn rational(&self) -> VelocityChangeTaskRationale
Returns the enum value of rational, or the default if the field is set to an invalid enum value.
Sourcepub fn set_rational(&mut self, value: VelocityChangeTaskRationale)
pub fn set_rational(&mut self, value: VelocityChangeTaskRationale)
Sets rational to the provided enum value.
Sourcepub fn add_target_x(&self) -> u32
pub fn add_target_x(&self) -> u32
Returns the value of add_target_x, or the default value if add_target_x is unset.
Sourcepub fn add_target_y(&self) -> u32
pub fn add_target_y(&self) -> u32
Returns the value of add_target_y, or the default value if add_target_y is unset.